@@ -47,9 +47,9 @@ our @DNS_FALLBACK; # some public dns servers as fallback
 
    my $ipv4 = $prep->(
       ["08080808", "08080404"], # 8.8.8.8, 8.8.4.4 - google public dns
-#      ["d1f40003", "d1f30004"], # v209.244.0.3/4 - resolver1/2.level3.net - status unknown
-      ["04020201", "04020203", "04020204", "04020205", "04020206"], # v4.2.2.1/3/4/5/6 - vnsc-pri.sys.gtei.net - effectively public
-      ["cdd22ad2", "4044c8c8"], # 205.210.42.205, 64.68.200.200 - cache1/2.dnsresolvers.com - verified public
+##      ["d1f40003", "d1f30004"], # v209.244.0.3/4 - resolver1/2.level3.net - status unknown
+##      ["04020201", "04020203", "04020204", "04020205", "04020206"], # v4.2.2.1/3/4/5/6 - vnsc-pri.sys.gtei.net - effectively public
+##      ["cdd22ad2", "4044c8c8"], # 205.210.42.205, 64.68.200.200 - cache1/2.dnsresolvers.com - verified public
 #      ["8d010101"], # 141.1.1.1 - cable&wireless - status unknown
    );
 
@@ -385,11 +385,25 @@ our %type_id = (
    minfo =>  14,
    mx    =>  15,
    txt   =>  16,
+   sig   =>  24,
+   key   =>  25,
+   gpos  =>  27, # rfc1712
    aaaa  =>  28,
+   loc   =>  29, # rfc1876
    srv   =>  33,
    naptr =>  35, # rfc2915
    dname =>  39, # rfc2672
    opt   =>  41,
+   ds    =>  43, # rfc4034
+   sshfp =>  44, # rfc4255
+   rrsig =>  46, # rfc4034
+   nsec  =>  47, # rfc4034
+   dnskey=>  48, # rfc4034
+   smimea=>  53, # rfc8162
+   cds   =>  59, # rfc7344
+   cdnskey=> 60, # rfc7344
+   openpgpkey=> 61, # rfc7926
+   csync =>  62, # rfc7929
    spf   =>  99,
    tkey  => 249,
    tsig  => 250,
@@ -397,6 +411,7 @@ our %type_id = (
    axfr  => 252,
    mailb => 253,
    "*"   => 255,
+   uri   => 256,
 );
 
 our %type_str = reverse %type_id;
@@ -698,7 +713,7 @@ resolver object.
 The resolver is created with the following parameters:
 
    untaint          enabled
-   max_outstanding  $ENV{PERL_ANYEVENT_MAX_OUTSTANDING_DNS}
+   max_outstanding  $ENV{PERL_ANYEVENT_MAX_OUTSTANDING_DNS} (default 10)
 
 C<os_config> will be used for OS-specific configuration, unless
 C<$ENV{PERL_ANYEVENT_RESOLV_CONF}> is specified, in which case that file
@@ -722,7 +737,7 @@ sub resolver() {
    $RESOLVER || do {
       $RESOLVER = new AnyEvent::DNS
          untaint         => 1,
-         max_outstanding => $ENV{PERL_ANYEVENT_MAX_OUTSTANDING_DNS}*1 || 1,
+         max_outstanding => $ENV{PERL_ANYEVENT_MAX_OUTSTANDING_DNS}*1 || 10,
       ;
 
       $ENV{PERL_ANYEVENT_RESOLV_CONF}
@@ -812,7 +827,7 @@ sub new {
    if (socket my $fh4, AF_INET , Socket::SOCK_DGRAM(), 0) {
       ++$got_socket;
 
-      AnyEvent::Util::fh_nonblocking $fh4, 1;
+      AnyEvent::fh_unblock $fh4;
       $self->{fh4} = $fh4;
       $self->{rw4} = AE::io $fh4, 0, sub {
          if (my $peer = recv $fh4, my $pkt, MAX_PKT, 0) {
@@ -825,7 +840,7 @@ sub new {
       ++$got_socket;
 
       $self->{fh6} = $fh6;
-      AnyEvent::Util::fh_nonblocking $fh6, 1;
+      AnyEvent::fh_unblock $fh6;
       $self->{rw6} = AE::io $fh6, 0, sub {
          if (my $peer = recv $fh6, my $pkt, MAX_PKT, 0) {
             $wself->_recv ($pkt, $peer);
